==> http_mock_adapter-0.1.4.tar.gz: CONTRIBUTING.md <==
# Contributing Guidelines

:tada: First of all, thank you for considering contributing! :tada:

Here you will find some guidelines on how to contribute. Feel free to propose changes to this document if you think something is missing or needs to be clarified.

## Code of Conduct

Always try your best to make a positive impact on this project and its community. By participating, you are expected to uphold the [Code of Conduct](CODE_OF_CONDUCT.md). Please report any unacceptable behavior to info@lomsa.com.

## Contributing Guides

First time contributing? You can learn more about contributing to open source projects through GitHub's [wonderful open source guides](https://opensource.guide/how-to-contribute/).

### :bug: Reporting a Problem

Before you open a new issue, check to see if the problem has [already been reported](https://github.com/lomsa-dev/http-mock-adapter/issues). If it has and **the issue is still open**, add a comment to the existing issue instead of creating a new one.

> **Note:** If you find a **closed** issue that seems to address the same thing that you've found, open a new issue and include a link to the original one.

When you open an issue, try to be as descriptive as possible. Add any relevant screenshots so that the problem can be identified quickly.

### :sparkles: Opening a Pull Request

> A lot of the following information was inspired by [opensource.guide](https://opensource.guide/how-to-contribute/), a great site to learn all about open source software.

If you've fixed a bug, started working on an enhancement, or done something else, you can [create a pull request](https://github.com/lomsa-dev/http-mock-adapter/pulls) to start a conversation about your changes.

A pull request doesn't necessarily have to include finished work. It may be better to open a PR early on so that you can get feedback on your contribution. Just mention that it's a work in progress and keep adding commits.

Here's how to contribute and submit your pull request:

1. [**Fork the repository**](https://help.github.com/articles/fork-a-repo/) and clone it locally. Add the original repository as a remote and pull in changes every so often so that you stay up to date with the project.
2. [**Create a branch**](https://guides.github.com/introduction/flow/) from `develop` for your changes.
3. **Add, commit, and push** your changes to your branch.
4. **Test out your changes.** Make sure that they work as you intended.
5. [**Open a pull request**](https://github.com/lomsa-dev/http-mock-adapter/pulls) to merge your branch into `develop`.
   - Reference any issues related to your PR (e.g. "Resolves #123").
   - Describe your changes in detail and include screenshots if necessary.
6. :sunglasses: Sit back, relax, and wait for your PR to be reviewed. You might have to tweak your contribution or elaborate on your changes. That's OK, don't be afraid to justify your reasoning and ask questions.

Thank you for reading through this contributing guide and welcome to the community! :v: :tada:

==> http_mock_adapter-0.4.1.tar.gz: CONTRIBUTING.md <==
# Contributing Guidelines

:tada: First of all, thank you for considering contributing! :tada:

Here you will find some guidelines on how to contribute. Feel free to propose changes to this document if you think something is missing or needs to be clarified.

## Code of Conduct

Always try your best to make a positive impact on this project and its community. By participating, you are expected to uphold the [Code of Conduct](CODE_OF_CONDUCT.md). Please report any unacceptable behavior to info@lomsa.com.

## Contributing Guides

First time contributing? You can learn more about contributing to open source projects through GitHub's [wonderful open source guides](https://opensource.guide/how-to-contribute/).

### :bug: Reporting a Problem

Before you open a new issue, check to see if the problem has [already been reported](https://github.com/lomsa-dev/http-mock-adapter/issues). If it has and **the issue is still open**, add a comment to the existing issue instead of creating a new one.

> **Note:** If you find a **closed** issue that seems to address the same thing that you've found, open a new issue and include a link to the original one.

When you open an issue, try to be as descriptive as possible. Add any relevant screenshots so that the problem can be identified quickly.

### :sparkles: Opening a Pull Request

> A lot of the following information was inspired by [opensource.guide](https://opensource.guide/how-to-contribute/), a great site to learn all about open source software.

If you've fixed a bug, started working on an enhancement, or done something else, you can [create a pull request](https://github.com/lomsa-dev/http-mock-adapter/pulls) to start a conversation about your changes.

A pull request doesn't necessarily have to include finished work. It may be better to open a PR early on so that you can get feedback on your contribution. Just mention that it's a work in progress and keep adding commits.

Here's how to contribute and submit your pull request:

1. [**Fork the repository**](https://help.github.com/articles/fork-a-repo/) and clone it locally. Add the original repository as a remote and pull in changes every so often so that you stay up to date with the project.
2. [**Create a branch**](https://guides.github.com/introduction/flow/) from `main` for your changes.
3. **Add, commit, and push** your changes to your branch.
4. **Test out your changes.** Make sure that they work as you intended.
5. [**Open a pull request**](https://github.com/lomsa-dev/http-mock-adapter/pulls) to merge your branch into `main`.
   - Reference any issues related to your PR (e.g. "Resolves #123").
   - Describe your changes in detail and include screenshots if necessary.
6. :sunglasses: Sit back, relax, and wait for your PR to be reviewed. You might have to tweak your contribution or elaborate on your changes. That's OK, don't be afraid to justify your reasoning and ask questions.

Thank you for reading through this contributing guide and welcome to the community! :v: :tada:
